@@ -1749,7 +1749,11 @@ set_issubset(PySetObject *so, PyObject *other)
     Py_RETURN_TRUE;
 }
 
-PyDoc_STRVAR(issubset_doc, "Report whether another set contains this set.");
+PyDoc_STRVAR(issubset_doc,
+"issubset($self, other, /)\n\
+--\n\
+\n\
+Test whether every element in the set is in other.");
 
 static PyObject *
 set_issuperset(PySetObject *so, PyObject *other)
@@ -1781,7 +1785,11 @@ set_issuperset(PySetObject *so, PyObject *other)
     Py_RETURN_TRUE;
 }
 
-PyDoc_STRVAR(issuperset_doc, "Report whether this set contains another set.");
+PyDoc_STRVAR(issuperset_doc,
+"issuperset($self, other, /)\n\
+--\n\
+\n\
+Test whether every element in other is in the set.");
 
 static PyObject *
 set_richcompare(PySetObject *v, PyObject *w, int op)
